==> cactoos_0.48.orig.tar.gz: cactoos-0.48/src/test/java/org/cactoos/text/EndsWithTest.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2020 Yegor Bugayenko
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.cactoos.text;

import org.junit.jupiter.api.Test;
import org.llorllale.cactoos.matchers.Assertion;
import org.llorllale.cactoos.matchers.ScalarHasValue;

/**
 * Test case for {@link EndsWith}.
 * @since 1.0
 * @checkstyle JavadocMethodCheck (500 lines)
 */
final class EndsWithTest {

    @Test
    void textMatchesEnding() {
        new Assertion<>(
            "Text's ending must match pattern",
            new EndsWith(
                new TextOf("Elegant Object"),
                "Object"
            ),
            new ScalarHasValue<>(Boolean.TRUE)
        ).affirm();
    }

    @Test
    void textMismatchesEnding() {
        new Assertion<>(
            "Text's ending must not match pattern",
            new EndsWith(
                new TextOf("Java is awesome"),
                "good"
            ),
            new ScalarHasValue<>(Boolean.FALSE)
        ).affirm();
    }
}

==> cactoos_0.54.0.orig.tar.gz: cactoos-0.54.0/src/test/java/org/cactoos/text/EndsWithTest.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2022 Yegor Bugayenko
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.cactoos.text;

import org.junit.jupiter.api.Test;
import org.llorllale.cactoos.matchers.Assertion;
import org.llorllale.cactoos.matchers.HasValue;

/**
 * Test case for {@link EndsWith}.
 * @since 1.0
 * @checkstyle JavadocMethodCheck (500 lines)
 */
final class EndsWithTest {

    @Test
    void textMatchesEnding() {
        new Assertion<>(
            "Text's ending must match pattern",
            new EndsWith(
                new TextOf("Elegant Object"),
                "Object"
            ),
            new HasValue<>(Boolean.TRUE)
        ).affirm();
    }

    @Test
    void textMismatchesEnding() {
        new Assertion<>(
            "Text's ending must not match pattern",
            new EndsWith(
                new TextOf("Java is awesome"),
                "good"
            ),
            new HasValue<>(Boolean.FALSE)
        ).affirm();
    }
}
